## -*- Mode: CPerl -*-
package Linux::Iwtools;

use 5.008007;
use strict;
use warnings;
use Carp;

require Exporter;
use AutoLoader;

our @ISA = qw(Exporter);

# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.

our @EXPORT      = qw();
our %EXPORT_TAGS = ( all => [qw(iwconfig iwlist PROC_NET_WIRELESS PROC_NET_DEV)] );
our @EXPORT_OK   = ( map { @$_ } values(%EXPORT_TAGS) );

our $VERSION = '0.01';



require XSLoader;
XSLoader::load('Linux::Iwtools', $VERSION);

# Preloaded methods go here.

# Autoload methods go after =cut, and are processed by the autosplit program.


1;
__END__

##----------------------------------------------------------------------
## PODs

# Below is stub documentation for your module. You'd better edit it!

=pod

=head1 NAME

Linux::Iwtools - Perl wrappers for (some) Linux Wireless Network Tools

=head1 SYNOPSIS

  use Linux::Iwtools qw(:all);

  $config = iwconfig();
  $config = iwconfig('wlan0');
  $status = iwconfig('wlan0', mode=>'managed', essid=>'any');

  $scanned = iwlist('scanning');
  $scanned = iwlist('wlan0', 'scanning');

=cut

##----------------------------------------------------------------------
## Description

=pod

=head1 DESCRIPTION

Linux::Iwtools contains perl wrappers for the command-line
programs 'iwconfig' and 'iwlist', without the need to fire
up a new process for each query.  Currently, only 'iwconfig'
and 'iwlist scanning' are supported.

=cut

##----------------------------------------------------------------------
## Exports

=pod

=head2 EXPORTS

None by default.


=head2 Exportable functions

The following functions are exportable:

 iwconfig
 iwlist
 PROC_NET_DEV
 PROC_NET_WIRELESS

You may import all available functions at once by:

 use Linux::Iwtools qw(:all);

=cut

##----------------------------------------------------------------------
## Functions

=pod

=head1 FUNCTIONS

=over 4

=item iwconfig()

=item iwconfig($device)

=item iwconfig($device, $key1=>$value1, $key2=>$value2, ...)

Runs the code for the command-line program iwconfig without
starting another process.  Parameters are as for iwconfig(8).
Returns (in the first and second forms) a reference to hash whose
keys are the names of network interfaces and whose values are either
hashes representing the extended wireless configuration for those
devices, or strings containing an error message.

One additional key 'status' always
appears in the returned hash, which containing the value with
which the command-line iwconfig would have exited.


=item iwlist('scanning')

=item iwlist($device,'scanning')

Runs the code for the command-line program 'iwlist' on device
$device with command 'scanning'.

Other parameters are as for iwlist(8), but do not yet return
particularly meaningful values to perl.
Returns (in the first and second forms) a reference to hash whose
keys are the names of network interfaces and whose values are either
references to arrays containing scan results for those interfaces
or strings containing an error message.  Each element of a scan
result array is itself a hash-reference which should be self-explanatory.

One additional key 'status' always
appears in the returned hash, which containing the value with
which the command-line iwconfig would have exited.

=back

=cut


##----------------------------------------------------------------------
## Footer

=pod

=head1 SEE ALSO

L<perl>

L<iwconfig>

L<iwlist>

Jean Tourrilhes' Wireless HOWTO and addenda:

 http://www.hpl.hp.com/personal/Jean_Tourrilhes/Linux/Wireless.html

=head1 AUTHOR

Jean Tourrilhes wrote and maintains the Linux Wireless Extensions
and tools.

Bryan Jurish, E<lt>moocow@ling.uni-potsdam.deE<gt>
wrote these wrappers.


=head1 COPYRIGHT AND LICENSE

iwconfig.c and iwlist.c are Copyright (C) 1997-2004 Jean Tourrilhes,
and are released under the terms of the GNU General Public License
Version 2.


The remaining portions of this distribution are

Copyright (C) 2005 by Bryan Jurish.

This library is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License Version 2,
or at your option, any later version.

=cut
